# Overview of build options:
#
# --define "kvers kernelver" - Build for kernel <version> instead of the
#                              current one. If you encounter problems then
#                              also define ksrc
#
# --define "ksrc /lib/modules/2.6.14-1.1637_FC4/build"
#
# Examples:
#
# To rebuild whole package for the running kernel:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" 
#
# To rebuild the zaptel kernel modules against a certain installed kernel # like 2.6.16-1.2133_FC5:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" \
#          --define "kvers 2.6.16-1.2133_FC5"
#
# if you have problems try this:
# rpmbuild -ba THIS.SPEC --target "$(uname -m)" \
#          --define "kvers 2.6.16-1.2133_FC5" \
#          --define "ksrc /lib/modules/2.6.16-1.2133_FC5/build"
#
# End of build options.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:     %{expand: %%define kernel %(uname -r)}}
%{!?kvers:      %{expand: %%define kvers %(uname -r)}}

%define is_fedora %(test -f /etc/fedora-release && echo 1 || echo 0)
%define is_rhel %(test -h /etc/redhat-release && echo 0 || echo 1)

%define prefix /usr
%define version 1.2.16
%define svnrev 1467
%define _libmoddir /lib/modules

%define maxpulse 80
%define rxflash 200

Summary: Driver for the Zaptel telephony adapters.
Name: zaptel
Version: %{version}
Release: 4%{?dist}
License: GPL
Group: Applications/System
URL: http://www.asterisk.org/
Source0: http://ftp.digium.com/pub/zaptel/zaptel-%{version}.tar.gz
Patch0: zaptel-1.2-RHEL4-CentOS4-kernel-bug.patch
Packager: Laimbock Consulting <asterisk@laimbock.com>
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: newt-devel
ExclusiveArch: i686

Requires: newt

%description
Drivers for Digium's Zaptel-based telephony drivers. The drivers offer support for Pseudo-TDM features. This package contains the Zaptel basic development files.

%package devel
Summary: Development package for %{name}
Group: Development/Libraries
Requires: zaptel = %{version}

%description devel
Use this package for building/developing applications against %{name}.

%package modules-%{kvers}
Summary: Zaptel kernel modules
Group: System Environment/Kernel
#BuildRequires: kernel-devel = %{kvers}
Requires: zaptel = %{version}
Requires: kernel = %{kvers}

%description modules-%{kvers}
The zaptel kernel modules. This package is built for kernel %{kvers} (%{_target_cpu}).


%prep
[ -d "%{buildroot}" ] || mkdir -p %{buildroot}

%setup -q -n %{name}-%{version}

# Enable small level 2 cache to prevent echo on celeron machines
perl -pi -e's,^/\* \#define CONFIG_CALC_XLAW \*/,#define CONFIG_CALC_XLAW,g' zconfig.h

# don't overwrite /etc/zaptel.conf so call it zaptel.conf.sample
perl -pi -e's,sample \$\(CONFIG_FILE\),sample \$\(INSTALL_PREFIX\)/etc/zaptel.conf.sample,g' Makefile

# fix RHEL & CentOS 2.6.9-34.EL bug. see bugs.digium.com/view.php?id=6425
# also see bugzilla.redhat.com/bugzilla/show_bug.cgi?id=180568
%if %is_rhel
echo "RHEL/CentOS detected. Applying patch0"
%patch0 -p1
%endif

%build
%{__make} clean
%{__make} %{?_smp_mflags} _libdir=%{_libdir} KVERS="%{?kvers:%{kvers}}%{!?kvers:%{kernel}}" USE_RTC=1 UDEVRULES=yes UDEVPERMISSIONS= BUILDVER=linux26

%install
[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}

# make the directories
%{__install} -m 755 -d %{buildroot}/etc
%{__install} -m 755 -d %{buildroot}/etc/udev/rules.d
%{__install} -m 755 -d %{buildroot}/usr/sbin
%{__install} -m 755 -d %{buildroot}/usr/share/man/man8

# create a blank modprobe.conf
touch %{buildroot}/etc/modprobe.conf

# install the bunch
%{makeinstall} %{?_smp_mflags} _libdir=%{_libdir} KVERS="%{?kvers:%{kvers}}%{!?kvers:%{kernel}}" INSTALL_PREFIX=%{buildroot} USE_RTC=1 BUILDVER=linux26 DYNFS=yes UDEVRULES=yes UDEVPERMISSIONS= MODCONF=$RPM_BUILD_ROOT/etc/modprobe.conf

# create libtonezone.so.1 and libtonzezone.so.0 so they get packaged too
/sbin/ldconfig -n %{buildroot}%{_libdir}

# remove the modprobe.conf.zaptel.bak file
%{__rm} -f %{buildroot}/etc/modprobe.conf.bak
%{__mv} %{buildroot}/etc/modprobe.conf %{buildroot}/etc/modprobe.conf.zaptel

# install startup, config and interface files not done by make install
%{__install} -m 700 ztspeed %{buildroot}/usr/sbin/ztspeed 
%{__install} -m 700 ztmonitor %{buildroot}/usr/sbin/ztmonitor 
%{__install} -m 700 torisatool %{buildroot}/usr/sbin/torisatool 
%{__install} -m 700 fxotune %{buildroot}/usr/sbin/fxotune 
%{__install} -m 700 zttest %{buildroot}/usr/sbin/zttest 
%{__install} -m 700 makefw %{buildroot}/usr/sbin/makefw 
%{__install} -m 700 gendigits %{buildroot}/usr/sbin/gendigits 
%{__install} -m 700 checkstack %{buildroot}/usr/sbin/checkstack

%{__mv} %{buildroot}/sbin/ztcfg %{buildroot}/usr/sbin
%{__mv} %{buildroot}/sbin/zttool %{buildroot}/usr/sbin
%{__rm} -rf %{buildroot}/sbin


if [ -d %{buildroot}/lib/modules/extra ]; then
	echo "Found incorrect location of the kernel modules."
	echo "Moving them to "%{buildroot}/lib/modules/%{kvers}/extra
	mkdir -p %{buildroot}/lib/modules/%{kvers}
	mv %{buildroot}/lib/modules/extra %{buildroot}/lib/modules/%{kvers}/extra
fi

%clean
[ "%{buildroot}" != '/' ] && rm -rf %{buildroot}
[ "$RPM_BUILD_DIR/%{name}-%{version}" != '/' ] && rm -rf $RPM_BUILD_DIR/%{name}-%{version}


%pre


%preun

%preun modules-%{kvers}

%post
if [ -x /usr/sbin/sestatus ] && (/usr/sbin/sestatus | grep "SELinux status:" | grep -q "enabled") ; then /sbin/restorecon -v %{_libdir}/libtonezone.so.1.0; fi

# update the ld database
/sbin/ldconfig

# deactivate the original zaptel udev rules in /etc/udev/rules.d/50-udev.rules
perl -pi -e's,KERNEL\=\=\"zap,#KERNEL\=\=\"zap,g' /etc/udev/rules.d/50-udev.rules
# activate the new zaptel.rules for udev
# /sbin/udevstart

%post modules-%{kvers}
# make sure the kernel knows about the new zaptel modules
/sbin/depmod -aeF /boot/System.map-%{kvers} %{kvers} > /dev/null || :


%postun
# update the ld database
/sbin/ldconfig

# activate the original zaptel udev rules in /etc/udev/rules.d/50-udev.rules
perl -pi -e's,#KERNEL\=\=\"zap,KERNEL\=\=\"zap,g' /etc/udev/rules.d/50-udev.rules
# let udev know the custom zaptel udev rules are gone
# /sbin/udevstart

%postun modules-%{kvers}
# make sure the kernel knows the zaptel modules are gone
/sbin/depmod -aF /boot/System.map-%{kvers} %{kvers} &> /dev/null || :


%files
%defattr(-,root,root)
# docs and example config files
%doc ChangeLog LICENSE README README.fxsusb README.udev README.Linux26 
# system files
%attr(0600,root,root)			 %{_sysconfdir}/zaptel.conf.sample
%attr(0755,root,root)			 %{_sysconfdir}/modprobe.conf.zaptel

# udev rules and permissions for zaptel
%attr(0644,root,root)	%{_sysconfdir}/udev/rules.d/zaptel.rules

# applications
%attr(0500,root,root)	%{_sbindir}/checkstack
%attr(0500,root,root)	%{_sbindir}/fxotune
%attr(0500,root,root)	%{_sbindir}/gendigits
%attr(0500,root,root)	%{_sbindir}/makefw
%attr(0500,root,root)	%{_sbindir}/torisatool
%attr(0500,root,root)	%{_sbindir}/ztcfg
%attr(0500,root,root)	%{_sbindir}/ztmonitor
%attr(0500,root,root)	%{_sbindir}/ztspeed
%attr(0500,root,root)	%{_sbindir}/zttest
%attr(0500,root,root)	%{_sbindir}/zttool

# tonezone library
%attr(0755,root,root)	 %{_libdir}/libtonezone.so.1.0

# man pages
%attr(0644,root,root)	%{_mandir}/man8/ztcfg.8.gz
%attr(0644,root,root)	%{_mandir}/man8/zttool.8.gz


%files devel
%defattr(-,root,root)
# header files
%attr(0644,root,root)	%{_includedir}/tonezone.h
%attr(0644,root,root)	%{_includedir}/linux/zaptel.h
%attr(0644,root,root)	%{_includedir}/linux/torisa.h
# lib symlinks
			%{_libdir}/libtonezone.so
			%{_libdir}/libtonezone.so.1

%files modules-%{kvers}
%defattr(-,root,root)
# kernel modules
%attr(0744,root,root)	%{_libmoddir}/%{kvers}/extra/*

%changelog
* Mon Apr 02 2007 Doug Pedley <dpedley@fonality.com> - 1.2.16-2
- Removed the creation of user and group 'asterisk' from "pre"

* Wed Sep 13 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.9.1-1
- based on 1.2.9.1
- patch0 to update 1.2.9 to svn revision 1467

* Mon Sep 11 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.9-1
- based on 1.2.9 (the svn version without the compile problem...)
- patch0 to update 1.2.9 to svn revision 1462
- FIXES
- rework zaptel-1.2-opts.patch
- rework zaptel-1.2-ztdummypll6.patch. Is now zaptel-1.2-ztdummypll7.patch
- Update firmware header generation tool to support paths being supplied with
   the filename (reported internally by Spiceland)

* Thu Aug 24 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.8-2
- based on 1.2.8
- fix the zaptel-1.2-RHEL4-CentOS4-kernel-bug.patch so it includes all
   CentOS kernels that have the issue

* Wed Aug 23 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.8-1
- based on 1.2.8

* Mon Aug 21 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.7-1.1332
- based on 1.2.7
- patch0 to update 1.2.6 to svn revision 1332
- add zaptel-1.2-usehist.patch for UK CallerID with a X100P card
- remove fxotune patch
- Makefile Add b410p support into 1.2 Makefile
- wct4xxp_base don't report the VPM servicing more spans than the card
   actually has

* Tue Aug 15 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.7-1.1309
- based on 1.2.7
- patch0 to update 1.2.6 to svn revision 1309
- rework zaptel-1.2-optflags.patch and zaptel-1.2-ztdummypll6.patch

* Sat Jun 24 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-1.1171
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1171
- replace fxotune with the one from trunk patched with #7264

* Thu Jun 15 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-2.1109
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1109
- rename ztdummy-pll module to ztdummypll
- activate ztdummypll in /etc/sysconfig/zaptel
- activate ztdummypll in /etc/rc.d/init.d/zaptel (in end of install section)
- add README.ztdummypll explaining how to find the optimal rtc_rate setting

* Wed Jun 14 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-1.1109
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1109
- add ztdummy-pll5 patch with multi-HZ logic (#6631)

* Tue Jun 6 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-1.1107
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1107
- fix some kernel-module unload logic

* Fri Jun 2 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-1.1104
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1104
- minor typo fix in error message

* Wed May 31 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.6-1.1098
- based on 1.2.6
- patch0 to update 1.2.6 to svn revision 1098
- add Tormenta 2 Quad T1/E1 (non-Digium clone) to PCI ID list

* Mon May 29 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1094
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1094
- small genmodconf fix
- fix buglet in module uninstall script

* Tue May 23 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1080
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1080
- more Makefile/genmodconf fixes

* Mon May 22 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1075
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1077
- small pciradio fix

* Fri May 19 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1075
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1075
- fixes for fxotune, wctdm, Makefile
- various udev related changes in Makefile
- fix perms of build_tools/genudevrules & genmodconf to 755
- disable genmodconf in the Makefile
- disable the udev "==" fix since the genudevrules script solves that
- specify BUILDVER=linux26 in %{makeinstall} or <module>.o (not .ko) is used
- ztdummy-pll disabled - needs a rework

* Wed May 17 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-2.1063
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1063
- fix the udev rules that went b0rken in svn rev 1060 so zaptel works again
- really disable the zaptel udev rules in 50-udev.rules when using our own

* Wed May 17 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1063
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1063
- disable ztdummy-rtc since it cause havoc on i686 boxes
- change ZT_MAXPULSETIMER so Flash works on Dutch analog phones
- change ZT_DEFAULT_RXFLASHTIME so a fast hangup is not seen as a hook flash

* Thu May 11 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1051
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1051
- add ztdummy-rtc based on the patch from #5971 (rework of ztdummy2)
- disable the xpp modules
- remove xpp/README.Astribank

* Thu May 4 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1022
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1022
- add ztdummy2 based on the patch from #5971
- rework zaptel-1.2-optflags patch: remove -O6 from KFLAGS, -O4 from CFLAGS
- rework zaptel-1.2-ztdummy-pll-250Hz patch to apply again...

* Sun Apr 16 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-2.1001
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1001
- add improved %preun module test & unloading logic

* Thu Apr 13 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1001
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1001
- only stop zaptel if the zaptel modules are being removed
- untangle the 250Hz/1000Hz patch again since CentOS 4.3 does not agree
- only apply the RHEL/CentOS kernel rwlock_t patch on RHEL/CentOS

* Tue Apr 11 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.1000
- based on 1.2.5
- patch0 to update 1.2.5 to svn revision 1000
- rework the zaptel-1.2.3-no_usb_owner.patch for 1.2.5
- unify ztdummy & ztdummy-pll 250Hz & 1000Hz patches

* Tue Apr 4 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.5-1.999
- based on 1.2.5
- no svn patch since svn.digium.com is down

* Fri Mar 17 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-2.984
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 984
- make /etc/rc.d/init.d/zaptel more resilient (more file checks)
- default to ztdummy only and disable all other modules when starting

* Thu Mar 16 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.984
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 984
- separate the ztdummy-pll patch to work with both 250Hz and 1000Hz kernels

* Tue Mar 14 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.980
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 980
- add patch to fix a RHEL4/CentOS4 kernel bug
- don't build this release on RHEL4/CentOS4 with gcc4. bad things will happen...

* Sun Mar 5 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.977
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 977
- add ztdummy-pll based on ztdummy, the 1000Hz patch and pll patch from #6631
- include README.Astribank from new xpp location

* Fri Mar 3 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-4.969
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 969
- create ztdummy-pll-250Hz patch for 1.2 from #6631

* Wed Mar 1 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-3.969
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 969
- display reason why /etc/rc.d/init.d/zaptel does not execute

* Mon Feb 27 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-2.969
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 969
- move sysconfig/zaptel to sysconfig/zaptel.sample so it will not interfere

* Fri Feb 24 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-2.967
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 967
- beautify %pre & %post messages

* Thu Feb 23 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.967
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 967

* Wed Feb 22 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.965
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 965

* Tue Feb 21 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.964
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 964
- rework logic to select paramters based on distro

* Sat Feb 18 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.961
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 961

* Fri Feb 17 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.4-1.959
- based on 1.2.4
- patch0 to update 1.2.4 to svn revision 959

* Wed Feb 15 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.3-1.950
- based on 1.2.3
- patch0 to update 1.2.3 to svn revision 950
- changed the zaptel init module defaults to ztdummy only

* Tue Feb 14 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.3-1.945
- based on 1.2.3
- patch0 to update 1.2.3 to svn revision 945
- disable the KB1 echo can and enable the MG2 echo can
- fix kernel version mismatch in wcusb.c
- disable PPC & X86_64 optimization flags. Let rpmbuild handle them
- use new zaptel-1.2.init so we get the fancy RH startup stuff
- add ExclusiveArch in the modules section
- add LICENSE to the %doc section
- added checkstack, gendigits and makefw apps
- put the zaptel kernel modules in the extra dir (was misc)
- change location of ztcfg in zaptel-1.2.init to /usr/sbin (was /sbin)
- change Group designation for zaptel

* Mon Feb 6 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.3-2.935
- add provisional patching for cross RHEL4/CentOS4/FC4 builds

* Fri Feb 3 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.3-1.935
- based on 1.2.3
- patch0 to update 1.2.3 to svn revision 935
- removed zaptel-1.2-USE_RTC-64bit.patch patch. fixed
- removed zaptel-1.2.0-udev.patch. fixed
- remove chmod 755 fix for build_tools. fixed
- build with default -O6 instead of -O2

* Thu Jan 5 2006 Laimbock Consulting <asterisk@laimbock.com> - 1.2.1-1.880
- based on the 1.2.1 release
- patch0 to update 1.2.1 to svn revision 880
- patch1 to force the use of RTC on x86_64
- patch2 to make ztdummy work with 250Hz (thanks dwmw2)
- fix missing exec mode in build_tools/*
- install included udev rules instead of separate ones

* Thu Dec 1 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-9
- zaptel-1.2.0-udev.patch to solve the sysfs API changes in kernels >= 2.6.15
- deactivate zaptel udev rules in 50-udev.rules
- fix custom zaptel.rules and activate those
- zaptel-1.2.0-ztdummy-ppc.patch to make ztdummy work on chrp/ppc

* Thu Dec 1 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-8
- make sure the RTC patch is applied on 32 bit ppc too (bad idea)

* Thu Dec 1 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-7
- really make the asterisk user/group check work...

* Tue Nov 29 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-6
- changes to make the specfile more compliant with the Fedora guidelines
- change gcc optimizations from -O4 and -O6 to -O2

* Tue Nov 29 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-5
- improve the ability to build zaptel modules against a different kernel
- only needs e.g. --define "kvers 2.6.14-1.1637_FC4" now

* Sat Nov 19 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-4
- put the zaptel kernel modules in a separate package
- add the ability to build the zaptel modules against a different kernel
- (based on code from the ati-fglrx.spec file. Thanks Thorsten!)

* Thu Nov 17 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-3
- 1.2.0 release
- fix the checks for user/group asterisk/asterisk (thanks z00dax!)

* Thu Nov 17 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-2
- 1.2.0 release
- add multi-arch build stuff

* Thu Nov 17 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-1
- 1.2.0 release
- cleanup for public consumption

* Sat Nov 12 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-rc2-1
- 1.2.0-rc2 release

* Wed Nov 10 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-rc1
- 1.2.0-rc1 release
- remove double entry for the zaptel modules in %files

* Tue Nov 08 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051104-1
- cvs HEAD from Nov 08 2005
- zaptel-USE_RTC-64bit.patch to force the usage of USE_RTC also on x86_64
- fix some module/moduledir permissions

* Mon Nov 07 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051104-1
- cvs HEAD from Nov 07 2005
- enable the zaptel-USE-RTC patch again

* Fri Nov 04 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051104-1
- cvs HEAD from Nov 04 2005
- MeetMe issue tracker: #4301 already applied

* Sun Oct 29 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051029-1
- cvs HEAD from Oct 29 2005
- the KB1 echo can is now selected by default so remove patch
- add patch to force the use of USE_RTC to bypass the 1000Hz jiffies issue
- move the 64 bit libs to /usr/lib64
- add the so.1 lib symlink

* Mon Oct 17 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051017-1
- cvs HEAD from Oct 17 2005

* Mon Oct 10 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20051010-1
- cvs HEAD from Oct 10 2005
- updated FC4 now comes with udev that has rules for zaptel but they don't have
- the proper ownership so I add my own zaptel udev rules. Let's hope this works
- force DYNFS to yes even if udevd isn't found. FC4 always uses udevd.

* Tue Sep 8 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs 20050908-1
- cvs HEAD from Sep 08 2005
- don't remove the asterisk user/group as it is needed by divactrl/capi

* Fri Sep 02 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050902-1
- cvs HEAD from Sep 02 2005
- enable USE_RTC on kernel < 2.6.12 as FC4 use 2.6.12 with upstream patches

* Thu Sep 01 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050901-1
- cvs HEAD from Sep 01 2005

* Wed Aug 31 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050831-1
- cvs HEAD from Aug 31 2005
- config.h Default to RINGBEGIN event being active...

* Tue Aug 30 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050830-1
- cvs HEAD from Aug 29 2005
- activate the new KB1 echo canceller
- put all the binaries in /usr/sbin

* Mon Aug 29 2005 Laimbock Consulting <asterisk@laimbock.com> - 1.2.0-cvs20050829-1
- cvs tag 1.2.0-beta1 from Aug 29 2005
- add asterisk user/group for proper udev device ownership
- create a zaptel udev rules file that actually works on FC4

* Thu Aug 25 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050825-1
- cvs HEAD from Aug 25 2005
- detect distro and put zaptel modules in the proper dir
- for CentOS: ./extra & for FC4 ./misc

* Sun Aug 14 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050814-1FC4
- on FC4 the modules are put in misc *not* extra

* Sun Aug 14 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050814-1
- cvs HEAD from Aug 14 2005
- split off header files and lib symlinks in a devel package
- always build ztclock with -lm so FC4/i686 & CentOS/PPC stops complaining
- move /etc/zaptel.conf to /etc/zaptel.conf.sample to save previous setup
- create /etc/modprobe.conf.zaptel file. include it in your /etc/modprobe.conf

* Mon Aug 08 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050808-1
- cvs HEAD from Aug 08 2005

* Wed Aug 03 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050803-1
- cvs HEAD from Aug 03 2005

* Mon Aug 01 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050801-2
- cvs HEAD from Aug 01 2005
- make sure ztclock compiles on PPC too

* Mon Aug 01 2005 Laimbock Consulting <asterisk@laimbock.com> - cvs20050801-1
- cvs HEAD from Aug 01 2005
- add separate udev zaptel files
- add zaptel-cvs20050801_zconfig.h_TDM_REVH_MATCHALL.patch
- add zaptel-cvs20050801_zconfig.h_MMX.patch but disable
